"""
FNV hash test suite.

Derived from http://isthe.com/chongo/src/fnv/test_fnv.c
"""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

import fnvhash
from fnvhash.test import vector
from unittest import TestCase

class FNVTest(TestCase):
    """
    FNV hash test suite.
    """

    def test_fnv0_32(self):
        """
        Tests the 32 bit FNV-0 hash implementation.
        """
        for string, expected_hval in vector.fnv0_32_vector.items():
            result = fnvhash.fnv0_32(string)
            self.assertEqual(result, expected_hval)

    def test_fnv1_32(self):
        """
        Tests the 32 bit FNV-1 hash implementation.
        """
        for string, expected_hval in vector.fnv1_32_vector.items():
            result = fnvhash.fnv1_32(string)
            self.assertEqual(result, expected_hval)

    def test_fnv1a_32(self):
        """
        Tests the 32 bit FNV-1a hash implementation.
        """
        for string, expected_hval in vector.fnv1a_32_vector.items():
            result = fnvhash.fnv1a_32(string)
            self.assertEqual(result, expected_hval)

    def test_fnv0_64(self):
        """
        Tests the 64 bit FNV-0 hash implementation.
        """
        for string, expected_hval in vector.fnv0_64_vector.items():
            result = fnvhash.fnv0_64(string)
            self.assertEqual(result, expected_hval)

    def test_fnv1_64(self):
        """
        Tests the 64 bit FNV-1 hash implementation.
        """
        for string, expected_hval in vector.fnv1_64_vector.items():
            result = fnvhash.fnv1_64(string)
            self.assertEqual(result, expected_hval)

    def test_fnv1a_64(self):
        """
        Tests the 64 bit FNV-1a hash implementation.
        """
        for string, expected_hval in vector.fnv1a_64_vector.items():
            result = fnvhash.fnv1a_64(string)
            self.assertEqual(result, expected_hval)



from setuptools import setup

setup(
    name='fnvhash',
    version='0.1.0',
    description='Pure Python FNV hash implementation',
    author='Lorenz Schori',
    author_email='lo@znerol.ch',
    url='https://github.com/znerol/py-fnvhash',
    packages=['fnvhash'],
    test_suite="fnvhash.test",
    zip_safe=True,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Topic :: Internet',
        'Topic :: Software Development',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities'
    ]
)
